==> 0.5.1.tar.gz: lib/hash_generator.dart <==
library hash_generator;

import 'dart:math';

/// O Gerador do hash.
class HashGenerator {
  static int _maxValue = 500;
  static List<String> _caracteres = [""];

  /// Retorna o Código hash
  static String generate(
      {int lenght = 16,
      bool withLetter = true,
      bool withNumber = true,
      bool withSymbol = true,
      String startWith = "",
      String endWith = ""}) {
    String resultado = "";

    if (lenght > _maxValue) {
      throw ("Valor máximo para o Hash é de $_maxValue caracteres.");
    }
    if (startWith.length > lenght) {
      throw ("A quantidade de caracteres no StartWith(${startWith.length}) deve ser menor que o total no Lenght($lenght).");
    }
    if (endWith.length > lenght) {
      throw ("A quantidade de caracteres no EndWith(${endWith.length}) deve ser menor que o total no Lenght($lenght).");
    }
    if ((startWith.length + endWith.length) > lenght) {
      throw ("A quantidade de caracteres somados entre o StartWith(${startWith.length}) e o EndWith(${endWith.length}) devem ser menor que o total no Lenght($lenght).");
    }
    if (withLetter) {
      _caracteres.addAll(_letras());
    }
    if (withNumber) {
      _caracteres.addAll(_numeros());
    }
    if (withSymbol) {
      _caracteres.addAll(_simbolos());
    }


    for (int i = 0; i < lenght - (startWith.length + endWith.length); i++) {
      resultado += _caracteres.elementAt(Random().nextInt(_caracteres.length));
    }

    return startWith.toString() + resultado + endWith.toString();
  }

  static List<String> _letras() {
    List<String> letras = List();
    letras.addAll([
      'a',
      'b',
      'c',
      'd',
      'e',
      'f',
      'g',
      'h',
      'i',
      'j',
      'l',
      'm',
      'n',
      'o',
      'p',
      'q',
      'r',
      's',
      't',
      'u',
      'v',
      'x',
      'z',
      'k',
      'w',
      'y',
      'A',
      'B',
      'C',
      'D',
      'E',
      'F',
      'G',
      'H',
      'I',
      'J',
      'L',
      'M',
      'N',
      'O',
      'P',
      'Q',
      'R',
      'S',
      'T',
      'U',
      'V',
      'X',
      'Z',
      'K',
      'W',
      'Y',
    ]);
    return letras;
  }

  static List<String> _numeros() {
    List<String> numeros = [
      '0',
      '1',
      '2',
      '3',
      '4',
      '5',
      '6',
      '7',
      '8',
      '9',
    ];
    return numeros;
  }

  static List<String> _simbolos() {
    List<String> simbolos = [
      '!',
      '@',
      '#',
      '^',
      '%',
      '&',
      '*',
      '-',
      '_',
      '+',
    ];
    return simbolos;
  }
}

==> 0.5.2.tar.gz: lib/hash_generator.dart <==
library hash_generator;

import 'dart:math';

/// O Gerador do hash.
class HashGenerator {
  static int _maxValue = 500;
  static List<String> _caracteres = [""];

  /// Retorna o Código hash
  static String generate(
      {int lenght = 16,
      bool withLetter = true,
      bool withNumber = true,
      bool withSymbol = true,
      String startWith = "",
      String endWith = ""}) {
    String resultado = "";

    if (lenght == 0) {
      throw ("O sistema não pode gerar um hash com ($lenght) caracteres.");
    }
    if (lenght > _maxValue) {
      throw ("Valor máximo para o Hash é de ($_maxValue) caracteres.");
    }
    if (startWith.length > lenght) {
      throw ("A quantidade de caracteres no StartWith(${startWith.length}) deve ser menor que o total no Lenght($lenght).");
    }
    if (endWith.length > lenght) {
      throw ("A quantidade de caracteres no EndWith(${endWith.length}) deve ser menor que o total no Lenght($lenght).");
    }
    if ((startWith.length + endWith.length) > lenght) {
      throw ("A quantidade de caracteres somados entre o StartWith(${startWith.length}) e o EndWith(${endWith.length}) devem ser menor que o total no Lenght($lenght).");
    }
    if (withLetter) {
      _caracteres.addAll(_letras());
    }
    if (withNumber) {
      _caracteres.addAll(_numeros());
    }
    if (withSymbol) {
      _caracteres.addAll(_simbolos());
    }


    for (int i = 0; i < lenght - (startWith.length + endWith.length); i++) {
      resultado += _caracteres.elementAt(Random().nextInt(_caracteres.length));
    }

    return startWith.toString() + resultado + endWith.toString();
  }

  static List<String> _letras() {
    List<String> letras = List();
    letras.addAll([
      'a',
      'b',
      'c',
      'd',
      'e',
      'f',
      'g',
      'h',
      'i',
      'j',
      'l',
      'm',
      'n',
      'o',
      'p',
      'q',
      'r',
      's',
      't',
      'u',
      'v',
      'x',
      'z',
      'k',
      'w',
      'y',
      'A',
      'B',
      'C',
      'D',
      'E',
      'F',
      'G',
      'H',
      'I',
      'J',
      'L',
      'M',
      'N',
      'O',
      'P',
      'Q',
      'R',
      'S',
      'T',
      'U',
      'V',
      'X',
      'Z',
      'K',
      'W',
      'Y',
    ]);
    return letras;
  }

  static List<String> _numeros() {
    List<String> numeros = [
      '0',
      '1',
      '2',
      '3',
      '4',
      '5',
      '6',
      '7',
      '8',
      '9',
    ];
    return numeros;
  }

  static List<String> _simbolos() {
    List<String> simbolos = [
      '!',
      '@',
      '#',
      '^',
      '%',
      '&',
      '*',
      '-',
      '_',
      '+',
    ];
    return simbolos;
  }
}
